@@ -1,18 +1,15 @@
 /// Overview: Read, process and write.
+mod cli;
+mod common;
+
 use std::fs::{File, OpenOptions};
 use std::io::{BufReader, Read, Write};
 
 use anyhow::Result;
 use structopt::StructOpt;
 
-use crate::cli::Opt;
-use crate::cook::cook;
-
-mod cli;
-mod cook;
-mod node;
-mod rule;
-mod tree;
+use cli::Opt;
+use common::cook::cook;
 
 fn main() -> Result<()> {
     let Opt { input, output } = Opt::from_args();
